iamdata

package
v0.2.202512271 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ActionExists

func ActionExists(serviceKey string, actionName string) (bool, error)

ActionExists checks if an action exists for a given service.

func ActionsForService

func ActionsForService(serviceKey string) ([]string, error)

ActionsForService returns a list of action names for a given service.

func ConditionKeyExists

func ConditionKeyExists(serviceKey string, conditionKey string) (bool, error)

ConditionKeyExists checks if a condition key exists for a given service.

func ConditionKeysForService

func ConditionKeysForService(serviceKey string) ([]string, error)

ConditionKeysForService returns a list of condition key names for a given service.

func ResourceTypesExists

func ResourceTypesExists(serviceKey string, resourceTypeKey string) (bool, error)

ResourceTypesExists checks if a resource type exists for a given service.

func ResourceTypesForService

func ResourceTypesForService(serviceKey string) ([]string, error)

ResourceTypesForService returns a list of resource type names for a given service.

func ServiceExists

func ServiceExists(serviceName string) (bool, error)

ServiceExists checks if a service exists.

func ServiceKeys

func ServiceKeys() ([]string, error)

ServiceKeys returns a list of all IAM service keys.

func ServiceName

func ServiceName(serviceKey string) (string, error)

ServiceName returns the name of a service given its key.

func UpdatedAt

func UpdatedAt() (time.Time, error)

UpdatedAt returns the time the IAM data was last updated.

func Version

func Version() (string, error)

Version returns the version of the IAM data module.

Types

type AccessLevel

type AccessLevel string

AccessLevel is a custom type to restrict the values to specific strings

const (
	Read    AccessLevel = "Read"
	Write   AccessLevel = "Write"
	List    AccessLevel = "List"
	Tagging AccessLevel = "Tagging"
)

type Action

type Action struct {
	Name             string               `json:"name"`
	Description      string               `json:"description"`
	AccessLevel      AccessLevel          `json:"accessLevel"`
	ResourceTypes    []ActionResourceType `json:"resourceTypes"`
	ConditionKeys    []string             `json:"conditionKeys"`
	DependentActions []string             `json:"dependentActions"`
}

Action maps to the Action metadata available.

func ActionDetails

func ActionDetails(serviceKey string, actionName string) (Action, error)

ActionDetails returns the metadata for a given action within a service.

type ActionResourceType

type ActionResourceType struct {
	Name             string   `json:"name"`
	Required         bool     `json:"required"`
	ConditionKeys    []string `json:"conditionKeys"`
	DependentActions []string `json:"dependentActions"`
}

ActionResourceType maps to the resource type metadata that can be included in an action.

type Actions

type Actions map[string]Action

Actions is a map of action names to Action metadata.

type ConditionKeyType

type ConditionKeyType struct {
	Key         string `json:"key"`
	Description string `json:"description"`
	Type        string `json:"type"`
}

ConditionKeyType maps to the condition key metadata available.

func ConditionKeyDetails

func ConditionKeyDetails(serviceKey string, conditionKey string) (ConditionKeyType, error)

ConditionKeyDetails returns the metadata for a given condition key for a given service.

type ConditionKeysMap

type ConditionKeysMap map[string]ConditionKeyType

ConditionKeysMap is a map of condition key names to ConditionKeyType metadata.

type Metadata

type Metadata struct {
	Version   string    `json:"version"`
	UpdatedAt time.Time `json:"updatedAt"`
}

Metadata available for the module.

type ResourceType

type ResourceType struct {
	Key           string   `json:"key"`
	Arn           string   `json:"arn"`
	ConditionKeys []string `json:"conditionKeys"`
}

ResourceType maps to the resource type metadata available.

func ResourceTypesDetails

func ResourceTypesDetails(serviceKey string, resourceTypeKey string) (ResourceType, error)

ResourceTypesDetails returns the metadata for a given resource type for a given service.

type ResourceTypesMap

type ResourceTypesMap map[string]ResourceType

ResourceTypesMap is a map of resource type names to ResourceType metadata.

type ServiceKeyStrings

type ServiceKeyStrings []string

ServiceNames is a list of service keys.

type ServiceNameMap

type ServiceNameMap map[string]string

ServiceNameMap maps service keys to service names.

Jump to