Documentation
¶
Index ¶
- func ActionExists(serviceKey string, actionName string) (bool, error)
- func ActionsForService(serviceKey string) ([]string, error)
- func ConditionKeyExists(serviceKey string, conditionKey string) (bool, error)
- func ConditionKeysForService(serviceKey string) ([]string, error)
- func ResourceTypesExists(serviceKey string, resourceTypeKey string) (bool, error)
- func ResourceTypesForService(serviceKey string) ([]string, error)
- func ServiceExists(serviceName string) (bool, error)
- func ServiceKeys() ([]string, error)
- func ServiceName(serviceKey string) (string, error)
- func UpdatedAt() (time.Time, error)
- func Version() (string, error)
- type AccessLevel
- type Action
- type ActionResourceType
- type Actions
- type ConditionKeyType
- type ConditionKeysMap
- type Metadata
- type ResourceType
- type ResourceTypesMap
- type ServiceKeyStrings
- type ServiceNameMap
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ActionExists ¶
ActionExists checks if an action exists for a given service.
func ActionsForService ¶
ActionsForService returns a list of action names for a given service.
func ConditionKeyExists ¶
ConditionKeyExists checks if a condition key exists for a given service.
func ConditionKeysForService ¶
ConditionKeysForService returns a list of condition key names for a given service.
func ResourceTypesExists ¶
ResourceTypesExists checks if a resource type exists for a given service.
func ResourceTypesForService ¶
ResourceTypesForService returns a list of resource type names for a given service.
func ServiceExists ¶
ServiceExists checks if a service exists.
func ServiceKeys ¶
ServiceKeys returns a list of all IAM service keys.
func ServiceName ¶
ServiceName returns the name of a service given its key.
Types ¶
type AccessLevel ¶
type AccessLevel string
AccessLevel is a custom type to restrict the values to specific strings
const ( Read AccessLevel = "Read" Write AccessLevel = "Write" List AccessLevel = "List" Tagging AccessLevel = "Tagging" )
type Action ¶
type Action struct {
Name string `json:"name"`
Description string `json:"description"`
AccessLevel AccessLevel `json:"accessLevel"`
ResourceTypes []ActionResourceType `json:"resourceTypes"`
ConditionKeys []string `json:"conditionKeys"`
DependentActions []string `json:"dependentActions"`
}
Action maps to the Action metadata available.
type ActionResourceType ¶
type ActionResourceType struct {
Name string `json:"name"`
Required bool `json:"required"`
ConditionKeys []string `json:"conditionKeys"`
DependentActions []string `json:"dependentActions"`
}
ActionResourceType maps to the resource type metadata that can be included in an action.
type ConditionKeyType ¶
type ConditionKeyType struct {
Key string `json:"key"`
Description string `json:"description"`
Type string `json:"type"`
}
ConditionKeyType maps to the condition key metadata available.
func ConditionKeyDetails ¶
func ConditionKeyDetails(serviceKey string, conditionKey string) (ConditionKeyType, error)
ConditionKeyDetails returns the metadata for a given condition key for a given service.
type ConditionKeysMap ¶
type ConditionKeysMap map[string]ConditionKeyType
ConditionKeysMap is a map of condition key names to ConditionKeyType metadata.
type ResourceType ¶
type ResourceType struct {
Key string `json:"key"`
Arn string `json:"arn"`
ConditionKeys []string `json:"conditionKeys"`
}
ResourceType maps to the resource type metadata available.
func ResourceTypesDetails ¶
func ResourceTypesDetails(serviceKey string, resourceTypeKey string) (ResourceType, error)
ResourceTypesDetails returns the metadata for a given resource type for a given service.
type ResourceTypesMap ¶
type ResourceTypesMap map[string]ResourceType
ResourceTypesMap is a map of resource type names to ResourceType metadata.
type ServiceNameMap ¶
ServiceNameMap maps service keys to service names.